What's New
~~~~~~~~~~

These are new features and improvements of note in each release

.. contents:: `Releases`
    :depth: 1
    :local:
    :backlinks: top

.. include::  whatsnew/v0-0-4.rst
.. include::  whatsnew/v0-0-3.rst
.. include::  whatsnew/v0-0-2.rst
.. include::  whatsnew/v0-0-1.rst
